package io.renren.modules.admin.lecture.controller;

import java.util.Arrays;
import java.util.Map;

import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import io.renren.modules.admin.lecture.entity.LectureEntity;
import io.renren.modules.admin.lecture.service.LectureService;
import io.renren.common.utils.PageUtils;
import io.renren.common.utils.R;



/**
 * 演讲(报告)表
 *
 * @author chenshun
 * @email sunlightcs@gmail.com
 * @date 2020-02-11 14:36:45
 */
@RestController
@RequestMapping("admin/lecture")
public class LectureController {
    @Autowired
    private LectureService lectureService;

    /**
     * 列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("generator:lecture:list")
    public R list(@RequestParam Map<String, Object> params){
        PageUtils page = lectureService.queryPage(params);

        return R.ok().put("page", page);
    }


    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("generator:lecture:info")
    public R info(@PathVariable("id") Long id){
		LectureEntity lecture = lectureService.getById(id);

        return R.ok().put("lecture", lecture);
    }

    /**
     * 保存
     */
    @RequestMapping("/save")
    @RequiresPermissions("generator:lecture:save")
    public R save(@RequestBody LectureEntity lecture){
		lectureService.save(lecture);

        return R.ok();
    }

    /**
     * 修改
     */
    @RequestMapping("/update")
    @RequiresPermissions("generator:lecture:update")
    public R update(@RequestBody LectureEntity lecture){
		lectureService.updateById(lecture);

        return R.ok();
    }

    /**
     * 删除
     */
    @RequestMapping("/delete")
    @RequiresPermissions("generator:lecture:delete")
    public R delete(@RequestBody Long[] ids){
		lectureService.removeByIds(Arrays.asList(ids));

        return R.ok();
    }

}
