package io.renren.modules.admin.member.controller;

import java.util.Arrays;
import java.util.Map;

import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import io.renren.common.utils.PageUtils;
import io.renren.common.utils.R;
import io.renren.common.validator.ValidatorUtils;
import io.renren.common.validator.group.AddGroup;
import io.renren.common.validator.group.UpdateGroup;
import io.renren.modules.admin.member.entity.MemberEntity;
import io.renren.modules.admin.member.service.MemberService;
import io.renren.modules.sys.controller.AbstractController;


/**
 * 会员表
 *
 * @author chenshun
 * @email sunlightcs@gmail.com
 * @date 2020-01-17 11:29:03
 */
@RestController
@RequestMapping("/admin/member")
@Api("会员管理")
public class MemberController extends AbstractController  {
    @Autowired
    private MemberService memberService;

    /**
     * 列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("admin:member:list")
    @ApiOperation("列表")
    public R list(@RequestParam Map<String, Object> params){
        PageUtils page = memberService.queryPage(params);

        return R.ok().put("page", page);
    }

    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("admin:member:info")
    @ApiOperation("个人信息")
    public R info(@PathVariable("id") Long id){
		MemberEntity member = memberService.getById(id);

        return R.ok().put("member", member);
    }

    /**
     * 保存
     */
    @PostMapping("/save")
    @RequiresPermissions("admin:member:save")
    @ApiOperation("新增")
    public R save(@RequestBody MemberEntity member){
        ValidatorUtils.validateEntity(member, AddGroup.class);
		
		member.setCreateId(getUserId());
		memberService.saveMember(member);

        return R.ok();
    }

    /**
     * 修改
     */
    @PostMapping("/update")
    @RequiresPermissions("admin:member:update")
    @ApiOperation("修改")
    public R update(@RequestBody MemberEntity member){
        ValidatorUtils.validateEntity(member, UpdateGroup.class);
        member.setModifyId(getUserId());
		memberService.updateById(member);

        return R.ok();
    }

    /**
     * 删除
     */
    // @PostMapping("/delete")
    // @RequiresPermissions("admin:member:delete")
    // @ApiOperation("删除")
    // public R delete(@RequestBody Long[] ids){
	// 	memberService.removeByIds(Arrays.asList(ids));

    //     return R.ok();
    // }
    @PostMapping("/delete")
    @RequiresPermissions("admin:member:delete")
    @ApiOperation("删除")
    public R delete(@RequestBody Long[] ids){
        // memberService.removeByIds(Arrays.asList(ids));
        memberService.delete(ids);
        return R.ok();
    }

    @PostMapping("/status")
    @RequiresPermissions("admin:member:status")
    @ApiOperation("改变审核状态")
    public R status(@RequestBody Map<String, Object> param){
        // memberService.removeByIds(Arrays.asList(ids));
        Long id = Long.valueOf(param.get("id").toString());
        Integer status = Integer.valueOf(param.get("status").toString());
        System.out.println(id);
        System.out.println(status);
        int it = memberService.updateStatus(id, status);
        return R.ok();
    }
}
