package io.renren.modules.admin.member.service.impl;

import java.util.Arrays;
import java.util.Date;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.ibatis.session.Configuration;
import org.apache.ibatis.session.SqlSession;
import org.apache.commons.lang.RandomStringUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.shiro.crypto.hash.Sha256Hash;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import io.renren.common.utils.PageUtils;
import io.renren.common.utils.Query;
import io.renren.modules.admin.member.dao.MemberDao;
import io.renren.modules.admin.member.entity.MemberEntity;
import io.renren.modules.admin.member.service.MemberService;

@Service("memberService")
public class MemberServiceImpl extends ServiceImpl<MemberDao, MemberEntity> implements MemberService {
    @Autowired
    private SqlSession sqlSession;

    @Override
    public PageUtils queryPage(Map<String, Object> params) {
        String username = (String)params.get("username");
        String truename = (String)params.get("truename");
        // System.out.println(key);
        IPage<MemberEntity> page = this.page(
                new Query<MemberEntity>().getPage(params),
                new QueryWrapper<MemberEntity>()
                .like(StringUtils.isNotBlank(username),"username", username)
                .or()
                .like(StringUtils.isNotBlank(truename),"truename", truename)
        );

        return new PageUtils(page);
    }

    @Override
	@Transactional
    public void saveMember(MemberEntity member){
        member.setCreateTime(new Date());
        //sha256加密
		String salt = RandomStringUtils.randomAlphanumeric(20);
		member.setPassword(new Sha256Hash(member.getPassword(), salt).toHex());
		member.setSalt(salt);
		this.save(member); 
    }

    @Override
	@Transactional
    public void update(MemberEntity member) {
        member.setModifyTime(new Date());
        if(StringUtils.isBlank(member.getPassword())){
			member.setPassword(null);
		}else{
			member.setPassword(new Sha256Hash(member.getPassword(), member.getSalt()).toHex());
		}

        this.updateById(member);
    }

    @Override
    public void delete(Long[] ids) {
        baseMapper.deleteBatchIds(Arrays.asList(ids));
    }

    @Override
    public int updateStatus(Long id, Integer isCheck) {
        int itemp = baseMapper.updateStatus(id, isCheck);
        return itemp;
        // @Update("update member set is_check=#{is_check}  where id = #{id}")
    }
}